@@ -1,12 +1,17 @@
+# Standard Library
+from gettext import gettext as _
+
+# Lutris Modules
 from lutris.config import LutrisConfig
-from lutris.gui.dialogs import Dialog
+from lutris.gui.config import DIALOG_HEIGHT, DIALOG_WIDTH
 from lutris.gui.config.common import GameDialogCommon
-from lutris.gui.config import DIALOG_WIDTH, DIALOG_HEIGHT
+from lutris.gui.dialogs import Dialog
 
 
 class SystemConfigDialog(Dialog, GameDialogCommon):
+
     def __init__(self, parent=None):
-        super().__init__("System preferences", parent=parent)
+        super().__init__(_("System preferences"), parent=parent)
 
         self.game = None
         self.runner_name = None
