@@ -39,7 +39,7 @@ class residualvm(Runner):
     runner_options = [
         {
             "option": "fullscreen",
-            "label": _("Fullscreen mode"),
+            "label": _("Fullscreen"),
             "type": "bool",
             "default": False,
         },
