@@ -89,7 +89,7 @@ class winesteam(wine.wine):
             "help": _(
                 "The architecture of the Windows environment.\n"
                 "32-bit is recommended unless running "
-                "a 64-bit only game."
+                "64-bit only games."
             ),
         },
         {
@@ -160,17 +160,17 @@ class winesteam(wine.wine):
             {
                 "option": "default_win32_prefix",
                 "type": "directory_chooser",
-                "label": _("Default Wine prefix (32bit)"),
+                "label": _("Default Wine prefix (32-bit)"),
                 "default": os.path.join(settings.RUNNER_DIR, "winesteam/prefix"),
-                "help": _("Default prefix location for Steam (32 bit)"),
+                "help": _("Default prefix location for Steam (32-bit)"),
                 "advanced": True,
             },
             {
                 "option": "default_win64_prefix",
                 "type": "directory_chooser",
-                "label": _("Default Wine prefix (64bit)"),
+                "label": _("Default Wine prefix (64-bit)"),
                 "default": os.path.join(settings.RUNNER_DIR, "winesteam/prefix64"),
-                "help": _("Default prefix location for Steam (64 bit)"),
+                "help": _("Default prefix location for Steam (64-bit)"),
                 "advanced": True,
             },
         ]
